pub type SqlType = (Text, Int8, Int8, Int8, Int8, Int8, Timestamp, Int8, Nullable<Bytea>);Expand description
The SQL type of all of the columns on this table
pub type SqlType = (Text, Int8, Int8, Int8, Int8, Int8, Timestamp, Int8, Nullable<Bytea>);The SQL type of all of the columns on this table